@@ -4,7 +4,7 @@ from inewave._utils.registros import RegistroAn, RegistroFn, RegistroIn
 from inewave._utils.leitura import Leitura
 from inewave.config import MAX_ANOS_ESTUDO, MAX_CONFIGURACOES, MAX_ITERS
 from inewave.config import REES, NUM_CONFIGS_DGER
-from inewave.config import MESES, SUBMERCADOS
+from inewave.config import MESES, MESES_DF, SUBMERCADOS
 # Imports de módulos externos
 from datetime import timedelta
 import numpy as np  # type: ignore
@@ -268,6 +268,124 @@ class BlocoEcoDgerPMO(Bloco):
         pass
 
 
+class BlocoEafPastTendenciaHidrolPMO(Bloco):
+    """
+    Bloco de informações de afluências passadas para
+    tendência hidrológica localizado no arquivo `pmo.dat`.
+    """
+
+    str_inicio = "ENERGIAS AFLUENTES PASSADAS PARA A TENDENCIA HIDROLOGICA"
+    str_fim = ""
+
+    def __init__(self):
+        super().__init__(BlocoEafPastTendenciaHidrolPMO.str_inicio,
+                         BlocoEafPastTendenciaHidrolPMO.str_fim,
+                         True)
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object) -> bool:
+        if not isinstance(o, BlocoEafPastTendenciaHidrolPMO):
+            return False
+        bloco: BlocoEafPastTendenciaHidrolPMO = o
+        return self._dados.equals(bloco.dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df():
+            df = pd.DataFrame(tabela,
+                              columns=MESES_DF)
+            df["REE"] = rees
+            df = df[["REE"] + MESES_DF]
+            return df
+
+        # Pula as linhas iniciais
+        for _ in range(3):
+            arq.readline()
+        # Variáveis auxiliares
+        reg_sistema = RegistroAn(10)
+        reg_eaf = RegistroFn(8)
+        rees: List[str] = []
+        tabela = np.zeros((len(REES), len(MESES_DF)))
+        i = 0
+        while True:
+            linha: str = arq.readline()
+            # Confere se acabou
+            if "X-------" in linha:
+                self._dados = converte_tabela_em_df()
+                break
+            # Lê mais uma linha
+            rees.append(reg_sistema.le_registro(linha, 1))
+            tabela[i, :] = reg_eaf.le_linha_tabela(linha,
+                                                   14,
+                                                   3,
+                                                   len(MESES))
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoEafPastCfugaMedioPMO(Bloco):
+    """
+    Bloco de informações de afluências passadas para
+    tendência hidrológica localizado no arquivo `pmo.dat`.
+    """
+
+    str_inicio = "ENERGIAS AFLUENTES PASSADAS EM REFERENCIA A PRIMEIRA CONFIG"
+    str_fim = ""
+
+    def __init__(self):
+        super().__init__(BlocoEafPastCfugaMedioPMO.str_inicio,
+                         BlocoEafPastCfugaMedioPMO.str_fim,
+                         True)
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object) -> bool:
+        if not isinstance(o, BlocoEafPastCfugaMedioPMO):
+            return False
+        bloco: BlocoEafPastCfugaMedioPMO = o
+        return self._dados.equals(bloco.dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df():
+            df = pd.DataFrame(tabela,
+                              columns=MESES_DF)
+            df["REE"] = rees
+            df = df[["REE"] + MESES_DF]
+            return df
+
+        # Pula as linhas iniciais
+        for _ in range(3):
+            arq.readline()
+        # Variáveis auxiliares
+        reg_sistema = RegistroAn(10)
+        reg_eaf = RegistroFn(8)
+        rees: List[str] = []
+        tabela = np.zeros((len(REES), len(MESES_DF)))
+        i = 0
+        while True:
+            linha: str = arq.readline()
+            # Confere se acabou
+            if "X-------" in linha:
+                self._dados = converte_tabela_em_df()
+                break
+            # Lê mais uma linha
+            rees.append(reg_sistema.le_registro(linha, 1))
+            tabela[i, :] = reg_eaf.le_linha_tabela(linha,
+                                                   14,
+                                                   3,
+                                                   len(MESES))
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
 class BlocoConvergenciaPMO(Bloco):
     """
     Bloco com as informações de convergência do NEWAVE obtidas
@@ -512,7 +630,7 @@ class BlocoCustoOperacaoPMO(Bloco):
     existentes no arquivo `pmo.dat`.
     """
 
-    str_inicio = "PARCELA           V.ESPERADO  D.P. DO V.E."
+    str_inicio = "PARCELA           V.ESPERADO"
 
     componentes_custo = [
                          "GERACAO TERMICA   ",
@@ -595,8 +713,10 @@ class LeituraPMO(Leitura):
         """
         Cria a lista de blocos a serem lidos no arquivo parp.dat.
         """
-        eco_dger: List[Bloco] = [BlocoEcoDgerPMO()]
+        # eco_dger: List[Bloco] = [BlocoEcoDgerPMO()]
         convergencia: List[Bloco] = [BlocoConvergenciaPMO()]
+        eafpast: List[Bloco] = [BlocoEafPastTendenciaHidrolPMO(),
+                                BlocoEafPastCfugaMedioPMO()]
         risco_deficit: List[Bloco] = [BlocoRiscoDeficitENSPMO()]
         configs_exp: List[Bloco] = [BlocoConfiguracoesExpansaoPMO()
                                     for _ in range(3)]
@@ -608,8 +728,8 @@ class LeituraPMO(Leitura):
                                BlocoCustoOperacaoPMO()
                               ]
 
-        return (eco_dger +
-                convergencia +
+        return (convergencia +
+                eafpast +
                 risco_deficit +
                 configs_exp +
                 mars +
